//:://////////////////////////////////////////////
//:: qg_hardcore.nss (was/is rehash of k_def_buff
//:: Original Creator: Preston Watamaniuk
//::          Created: April 8, 2003
//:://////////////////////////////////////////////
//:: Modder: Qui-Gon Glenn
//:: Modified: Jan 29, 2011
//:: Thanks go to stoffe for adding the Suit check
//:: and illuminating proper implementation!!
//////////////////////////////////////////////////


/*  Buffs the target object based on the level of the main PC

    Default buffs have been replaced with values inspired by Talchia's Hardcore mod.
    Charisma Bonus for Jedi has been fixed - it was not finished by Bioware Corp.
    Strength Bonus for Jedi added per Talchia's original mod.
    This mod may a good bit harder than Talchia's, considering the fixed Charisma buff.

    Jedi (class) will get the following:
    Player Level 8+: +6 to Wisdom, +6 to Charisma, +6 to Strength, +75 Force Points, +75 Vitality Points. 
    Player Level 13+: +12 to Wisdom, +12 to Charisma, +6 to Strength, +125 Force Points, +125 Vitality Points.
    Player Level 17+: +20 to Wisdom, +20 to Charisma, +20 to Strength, +200 Force Points, +200 Vitality Points.

    Beasts (subrace) will get the following:
    Player Level 8+: +9 Strength, +6 Dexterity, +90 Vitality points. 
    Player Level 13+: +12 Strength, +10 Dexterity, +120 Vitality points.
    Player Level 17+: +20 Strength, +16 Dexterity, +200 Vitality points.

    Droids (race) will get the following:
    Player Level 8+: +9 Dexterity, +9 Constitution, +90 Vitality points.
    Player Level 13+: +12 Dexterity, +12 Constitution, +120 Vitality points.
    Player Level 17+: +20 Dexterity, +16 Constitution, +200 Vitality points. 

    Scoundrel, Soldier, Scout (class):
    Player Level 8+: +6 Dexterity, +6 Strength, +75 Vitality points.
    Player Level 13+: +12 Dexterity, +12 Strength, +130 Vitality points.
    Player Level 17+: +20 Dexterity, +20 Strength, +200 Vitality points.
*/

void main()
{
    if (GetPlayerRestrictMode())    // stoffe: Prevents buffs in the Space/Environment suit scenes
        return; 


    int nCharLevel = GetHitDice(GetFirstPC());
    int bValid = TRUE;
    effect eStatA, eStatB, eStatC, eStatD, eFP, eVP, eLink; 
    int nVP;

    //Apply the effects based on the type of creature.
    //JEDIS
    if(GetLevelByClass(CLASS_TYPE_JEDICONSULAR) > 0 ||
       GetLevelByClass(CLASS_TYPE_JEDIGUARDIAN) > 0 ||
       GetLevelByClass(CLASS_TYPE_JEDISENTINEL) > 0)
    {
        //Set up the effects based on the character level
        if(nCharLevel >= 8 && nCharLevel <= 12)
        {
            eStatA = EffectAbilityIncrease(ABILITY_WISDOM, 6);
            eStatB = EffectAbilityIncrease(ABILITY_DEXTERITY, 6);
            eStatC = EffectAbilityIncrease(ABILITY_CHARISMA, 6);
            eStatD = EffectAbilityIncrease(ABILITY_STRENGTH, 6);
            eFP = EffectTemporaryForcePoints(75);
            nVP = 75;
        }
        else if(nCharLevel >= 13 && nCharLevel <= 16)
        {
            eStatA = EffectAbilityIncrease(ABILITY_WISDOM, 12);
            eStatB = EffectAbilityIncrease(ABILITY_DEXTERITY, 12);
            eStatC = EffectAbilityIncrease(ABILITY_CHARISMA, 12);
            eStatD = EffectAbilityIncrease(ABILITY_STRENGTH, 12);
            eFP = EffectTemporaryForcePoints(125);
            nVP = 125;
        }
        else if (nCharLevel >= 17)
        {
            eStatA = EffectAbilityIncrease(ABILITY_WISDOM, 20);
            eStatB = EffectAbilityIncrease(ABILITY_DEXTERITY, 20);
            eStatC = EffectAbilityIncrease(ABILITY_CHARISMA, 20);
            eStatD = EffectAbilityIncrease(ABILITY_STRENGTH, 20);
            eFP = EffectTemporaryForcePoints(200);
            nVP = 200;
        }
        else
        {
            bValid = FALSE;
        }
        if(bValid == TRUE)
        {
            eLink = EffectLinkEffects(eStatA, eStatB); 
            eLink = EffectLinkEffects(eLink, eStatC);
            eLink = EffectLinkEffects(eLink, eStatD);
            eLink = EffectLinkEffects(eLink, eFP);
        }
    }
    //BEASTS
    else if(GetSubRace(OBJECT_SELF) == 2) //SUBRACE_BEAST
    {
        if(nCharLevel >= 8 && nCharLevel <= 12)
        {
            eStatA = EffectAbilityIncrease(ABILITY_STRENGTH, 9);
            eStatB = EffectAbilityIncrease(ABILITY_DEXTERITY, 6);
            nVP = 90;
        }
        else if(nCharLevel >= 13 & nCharLevel <= 16)
        {
            eStatA = EffectAbilityIncrease(ABILITY_STRENGTH, 12);
            eStatB = EffectAbilityIncrease(ABILITY_DEXTERITY, 10);
            nVP = 120;
        }
        else if(nCharLevel >= 17)
        {
            eStatA = EffectAbilityIncrease(ABILITY_STRENGTH, 20);
            eStatB = EffectAbilityIncrease(ABILITY_DEXTERITY, 16);
            nVP = 200;
        }   
        else
        {
            bValid = FALSE;
        }
        if(bValid == TRUE)
        {
            eLink = EffectLinkEffects(eStatA, eStatB);
        }
    }
    //DROIDS 
    else if(GetRacialType(OBJECT_SELF) == RACIAL_TYPE_DROID)
    {
        if(nCharLevel >= 8 && nCharLevel <= 12)
        {
            eStatA = EffectAbilityIncrease(ABILITY_DEXTERITY, 9);
            eStatB = EffectAbilityIncrease(ABILITY_CONSTITUTION, 9);
            nVP = 90;
        }
        else if(nCharLevel >= 13 & nCharLevel <= 16)
        {
            eStatA = EffectAbilityIncrease(ABILITY_DEXTERITY, 12);
            eStatB = EffectAbilityIncrease(ABILITY_CONSTITUTION, 12);
            nVP = 120;
        }
        else if(nCharLevel >= 17)
        {
            eStatA = EffectAbilityIncrease(ABILITY_DEXTERITY, 20);
            eStatB = EffectAbilityIncrease(ABILITY_CONSTITUTION, 16);
            nVP = 200;
        }
        else
        {
            bValid = FALSE;
        }
        if(bValid == TRUE)
        {
            eLink = EffectLinkEffects(eStatA, eStatB);
        }
    }
    else
    {
        //Set up the effects based on the character level
        if(nCharLevel >= 8 && nCharLevel <= 12)
        {
            eStatA = EffectAbilityIncrease(ABILITY_STRENGTH, 6);
            eStatB = EffectAbilityIncrease(ABILITY_DEXTERITY, 6);
            nVP = 75;
        }
        else if(nCharLevel >= 13 & nCharLevel <= 16)
        {
            eStatA = EffectAbilityIncrease(ABILITY_STRENGTH, 12);
            eStatB = EffectAbilityIncrease(ABILITY_DEXTERITY, 12);
            nVP = 130;
        }   
        else if(nCharLevel >= 17)
        {
            eStatA = EffectAbilityIncrease(ABILITY_STRENGTH, 20);
            eStatB = EffectAbilityIncrease(ABILITY_DEXTERITY, 20);
            nVP = 200;
        }
        else
        {
            bValid = FALSE;
        }
        if(bValid == TRUE)
        {
            eLink = EffectLinkEffects(eStatA, eStatB);
        }
    }
    if(nVP > 0)
    {
        nVP = GetMaxHitPoints(OBJECT_SELF) + nVP;
        SetMaxHitPoints(OBJECT_SELF, nVP);
        
    }
    if(bValid == TRUE)
    {
        ApplyEffectToObject(DURATION_TYPE_PERMANENT, eLink, OBJECT_SELF);
    }
}
